import QtQuick 2.0

Rectangle {
	id: dive
	color: "black"

	// some demo related properties
	property string color1: "white"
	property string color2: "black"
	property string title: "no-text"
	property string diveDetails: "no-text"
	property alias flick: flick
	property int fontSize: 24
	property int pad: 10

	// some important concept properties
	property alias anim: anim
	property var container: null

	// place the dive contents in a flick area
	Flickable {
		id: flick
		width: parent.width
		height: parent.height
		contentWidth: parent.width
		contentHeight: parent.height * 1.5

		// a swipe area inside the flick area
		SwipeArea {
			id: swipe
			width: parent.width
			height: parent.height
			preventStealing: false

			// slots for left swipe
			onSwipeLeft: {
				console.log("swipe left");
				if (container)
					container.navigate(container._DIRECTION_LEFT);
			}

			// slot for right swipe
			onSwipeRight: {
				console.log("swipe right");
				if (container)
					container.navigate(container._DIRECTION_RIGHT);
			}

			// a background to fill the entire flick and swipe area
			Rectangle {
				width: flick.contentWidth
				height: flick.contentHeight
				gradient: Gradient {
					GradientStop { position: 0.0; color: color1}
					GradientStop { position: 1.0; color: color2 }
				}
			}

			// dive title shadow (quick and dirty)
			Text {
				x: pad
				y: pad
				id: titleTextShadow
				text: title
				color: "black"
				font.pointSize: fontSize
				opacity: 0.9
			}

			// dive title
			Text {
				id: titleText
				x: titleTextShadow.x - 2
				y: titleTextShadow.y - 2
				text: title
				color: "white"
				font.pointSize: fontSize
			}

			// rect for the dive details
			Rectangle {
				id: diveDetailsRect
				x: pad
				y: titleText.y + titleText.height + pad
				width: parent.width - pad * 2
				height: dive.height / 2
				opacity: 0.9
				color: "white"
				border.color: "black"
				border.width: 1
			}

			// dive details text
			Text {
				id: diveDetailsText
				anchors.margins: pad
				anchors.fill: diveDetailsRect
				text: diveDetails
				color: "black"
				font.pointSize: fontSize
			}

			// profile image
			Image {
				id: profile
				x: pad
				y: diveDetailsRect.y + diveDetailsRect.height + pad
				width: parent.width - pad * 2
				height: dive.height - profile.y - 10
				source: "profile.png"
			}
		}

		onFlickStarted: {
			console.log("flick");
		}
	}

	// x animation
	NumberAnimation {
		id: anim
		target: dive
		properties: "x"
		duration: 300
		easing.type: Easing.OutQuad
	}

	// some random contents for the dive

	function randomTitle() {
		return "Dive #" + Math.floor(Math.random() * 100000);
	}

	function randomColor() {
		return "#" + Math.floor(Math.random() * 0xffffff).toString(16);
	}

	function randomDiveDetails() {
		var buddy = ["Linus", "Tomaz", "Dirk", "Miika", "Anton", "Robert"];
		var location = ["Finland", "Sweden", "Australia", "Germany", "Brazil", "Canada", "Norway"];
		var cyl = ["AL40", "AL50", "AL63", "AL72", "AL80", "AL100"];
		var weather = ["Cold", "Warm", "Hot", "Moist"];
		var rating = ["★☆☆☆☆", "★★☆☆☆", "★★★☆☆", "★★★★☆", "★★★★★"];
		var str = "";
		str += "Buddy: " + buddy[Math.floor(Math.random() * buddy.length)] + "\n";
		str += "Location: " + location[Math.floor(Math.random() * location.length)] + "\n";
		str += "Cyl: " + cyl[Math.floor(Math.random() * cyl.length)] + "\n";
		str += "Weather: " + weather[Math.floor(Math.random() * weather.length)] + "\n";
		str += "Rating: " + rating[Math.floor(Math.random() * rating.length)] + "\n";
		return str;
	}

	function randomize() {
		title = randomTitle();
		color1 = randomColor();
		color2 = randomColor();
		diveDetails = randomDiveDetails();
	}

	Component.onCompleted: {
		randomize();
	}
}
